package com.codigoparallevar.minicards.parts.buttons;

import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.util.Log;

import com.codigoparallevar.minicards.parts.Part;

import org.json.JSONException;
import org.json.JSONObject;

public class RoundButton implements Part {


    private int _xCenter;
    private int _yCenter;
    private final int _innerRadius;
    private final int _outerRadius;
    private final int _outerRadiusThickness = 10;

    public RoundButton(int xCenter, int yCenter, int innerRadius, int outerRadius) {
        _xCenter = xCenter;
        _yCenter = yCenter;
        _innerRadius = innerRadius;
        _outerRadius = outerRadius;
    }

    @Override
    public int getLeft() {
        return _xCenter - _outerRadius / 2;
    }

    @Override
    public int getRight() {
        return _xCenter + _outerRadius / 2;
    }

    @Override
    public int getTop() {
        return _yCenter - _outerRadius / 2;
    }

    @Override
    public int getBottom() {
        return _yCenter + _outerRadius / 2;
    }

    @Override
    public void draw(Canvas canvas) {
        Paint foregroundPaint = new Paint(Paint.ANTI_ALIAS_FLAG);
        foregroundPaint.setColor(Color.WHITE);

        Paint backgroundPaint = new Paint(Paint.ANTI_ALIAS_FLAG);
        backgroundPaint.setColor(Color.BLACK);

        canvas.drawCircle(_xCenter, _yCenter, _outerRadius, foregroundPaint);
        canvas.drawCircle(_xCenter, _yCenter, _outerRadius - _outerRadiusThickness, backgroundPaint);
        canvas.drawCircle(_xCenter, _yCenter, _innerRadius, foregroundPaint);
    }

    @Override
    public void move(int x, int y) {
        _xCenter = x;
        _yCenter = y;
    }

    @Override
    public void touched() {
        Log.d("RoundButton", "Round button touched");
    }

    @Override
    public JSONObject serialize() throws JSONException {
        JSONObject serialized = new JSONObject();

        serialized.put("x_center", _xCenter);
        serialized.put("y_center", _yCenter);
        serialized.put("inner_radius", _innerRadius);
        serialized.put("outer_radius", _outerRadius);
        serialized.put("outer_radius_thickness", _outerRadiusThickness);

        return serialized;
    }

    public static Part deserialize(JSONObject data) throws JSONException {
        int xCenter = data.getInt("x_center");
        int yCenter = data.getInt("y_center");

        int innerRadius = data.getInt("inner_radius");
        int outerRadius = data.getInt("outer_radius");

        return new RoundButton(xCenter, yCenter, innerRadius, outerRadius);
    }
}
